@@ -9,7 +9,7 @@ import numpy as np
 
 from ..core import average_recall_at_avg_proposals
 from .base import BaseDataset
-from .registry import DATASETS
+from .builder import DATASETS
 
 
 @DATASETS.register_module()
