@@ -5,12 +5,10 @@ from functools import partial
 import numpy as np
 from mmcv.parallel import collate
 from mmcv.runner import get_dist_info
-from mmcv.utils import build_from_cfg
+from mmcv.utils import Registry, build_from_cfg
 from torch.utils.data import DataLoader
 
-from .dataset_wrappers import RepeatDataset
-from .registry import DATASETS
-from .samplers import DistributedPowerSampler, DistributedSampler
+from .samplers import ClassSpecificDistributedSampler, DistributedSampler
 
 if platform.system() != 'Windows':
     # https://github.com/pytorch/pytorch/issues/973
@@ -20,6 +18,10 @@ if platform.system() != 'Windows':
     soft_limit = min(4096, hard_limit)
     resource.setrlimit(resource.RLIMIT_NOFILE, (soft_limit, hard_limit))
 
+DATASETS = Registry('dataset')
+PIPELINES = Registry('pipeline')
+BLENDINGS = Registry('blending')
+
 
 def build_dataset(cfg, default_args=None):
     """Build a dataset from config dict.
@@ -33,6 +35,7 @@ def build_dataset(cfg, default_args=None):
         Dataset: The constructed dataset.
     """
     if cfg['type'] == 'RepeatDataset':
+        from .dataset_wrappers import RepeatDataset
         dataset = RepeatDataset(
             build_dataset(cfg['dataset'], default_args), cfg['times'])
     else:
@@ -79,15 +82,20 @@ def build_dataloader(dataset,
     """
     rank, world_size = get_dist_info()
     sample_by_class = getattr(dataset, 'sample_by_class', False)
-    power = getattr(dataset, 'power', None)
 
     if dist:
         if sample_by_class:
-            assert power is not None
-            sampler = DistributedPowerSampler(dataset, world_size, rank, power)
+            dynamic_length = getattr(dataset, 'dynamic_length', True)
+            sampler = ClassSpecificDistributedSampler(
+                dataset,
+                world_size,
+                rank,
+                dynamic_length=dynamic_length,
+                shuffle=shuffle,
+                seed=seed)
         else:
             sampler = DistributedSampler(
-                dataset, world_size, rank, shuffle=shuffle)
+                dataset, world_size, rank, shuffle=shuffle, seed=seed)
         shuffle = False
         batch_size = videos_per_gpu
         num_workers = workers_per_gpu
