@@ -5,7 +5,7 @@ import numpy as np
 import torch
 from mmcv.parallel import DataContainer as DC
 
-from ..registry import PIPELINES
+from ..builder import PIPELINES
 
 
 def to_tensor(data):
@@ -276,6 +276,8 @@ class FormatShape:
             results (dict): The resulting dict to be modified and passed
                 to the next transform in pipeline.
         """
+        if not isinstance(results['imgs'], np.ndarray):
+            results['imgs'] = np.array(results['imgs'])
         imgs = results['imgs']
         # [M x H x W x C]
         # M = 1 * N_crops * N_clips * L
