@@ -146,7 +146,8 @@ class PoseDecode:
     applicable).
     """
 
-    def _load_kp(self, kp, frame_inds):
+    @staticmethod
+    def _load_kp(kp, frame_inds):
         """Load keypoints given frame indices.
 
         Args:
@@ -156,7 +157,8 @@ class PoseDecode:
 
         return [x[frame_inds].astype(np.float32) for x in kp]
 
-    def _load_kpscore(self, kpscore, frame_inds):
+    @staticmethod
+    def _load_kpscore(kpscore, frame_inds):
         """Load keypoint scores given frame indices.
 
         Args:
@@ -189,7 +191,7 @@ class PoseDecode:
         return results
 
     def __repr__(self):
-        repr_str = (f'{self.__class__.__name__}()')
+        repr_str = f'{self.__class__.__name__}()'
         return repr_str
 
 
