@@ -6,12 +6,12 @@ import torch.nn as nn
 
 from ...localization import temporal_iop, temporal_iou
 from ..builder import LOCALIZERS, build_loss
-from .base import BaseLocalizer
+from .base import BaseTAPGenerator
 from .utils import post_processing
 
 
 @LOCALIZERS.register_module()
-class BMN(BaseLocalizer):
+class BMN(BaseTAPGenerator):
     """Boundary Matching Network for temporal action proposal generation.
 
     Please refer `BMN: Boundary-Matching Network for Temporal Action Proposal
@@ -52,7 +52,7 @@ class BMN(BaseLocalizer):
                  hidden_dim_1d=256,
                  hidden_dim_2d=128,
                  hidden_dim_3d=512):
-        super(BaseLocalizer, self).__init__()
+        super().__init__()
 
         self.tscale = temporal_dim
         self.boundary_ratio = boundary_ratio
