@@ -3,8 +3,7 @@ import torch
 import torch.nn as nn
 from mmcv.cnn import ConvModule, constant_init, normal_init, xavier_init
 
-from ..builder import build_loss
-from ..registry import NECKS
+from ..builder import NECKS, build_loss
 
 
 class Identity(nn.Module):
