@@ -60,6 +60,17 @@ class BaseRecognizer(nn.Module, metaclass=ABCMeta):
             self.backbone.classifier = nn.Identity()
             self.backbone.fc = nn.Identity()
             self.backbone_from = 'torchvision'
+        elif backbone['type'].startswith('timm.'):
+            try:
+                import timm
+            except (ImportError, ModuleNotFoundError):
+                raise ImportError('Please install timm to use this '
+                                  'backbone.')
+            backbone_type = backbone.pop('type')[5:]
+            # disable the classifier
+            backbone['num_classes'] = 0
+            self.backbone = timm.create_model(backbone_type, **backbone)
+            self.backbone_from = 'timm'
         else:
             self.backbone = builder.build_backbone(backbone)
 
@@ -113,11 +124,11 @@ class BaseRecognizer(nn.Module, metaclass=ABCMeta):
         """Initialize the model network weights."""
         if self.backbone_from in ['mmcls', 'mmaction2']:
             self.backbone.init_weights()
-        elif self.backbone_from == 'torchvision':
+        elif self.backbone_from in ['torchvision', 'timm']:
             warnings.warn('We do not initialize weights for backbones in '
-                          'torchvision, since the weights for backbones in '
-                          'torchvision are initialized in their __init__ '
-                          'functions. ')
+                          f'{self.backbone_from}, since the weights for '
+                          f'backbones in {self.backbone_from} are initialized'
+                          'in their __init__ functions.')
         else:
             raise NotImplementedError('Unsupported backbone source '
                                       f'{self.backbone_from}!')
@@ -140,6 +151,8 @@ class BaseRecognizer(nn.Module, metaclass=ABCMeta):
         if (hasattr(self.backbone, 'features')
                 and self.backbone_from == 'torchvision'):
             x = self.backbone.features(imgs)
+        elif self.backbone_from == 'timm':
+            x = self.backbone.forward_features(imgs)
         else:
             x = self.backbone(imgs)
         return x
